@@ -1,8 +1,6 @@
 import React from 'react'
 import {gettext} from 'system/l10n'
-import {Button, Box, DialogTitle, IconButton, Typography} from 'system/components'
-import WindowCloseIcon from '@mui/icons-material/Cancel'
-import HelpIcon from '@mui/icons-material/HelpCenterOutlined'
+import {Button, Box, DialogTitle, IconButton, MaterialIcon, Typography} from 'system/components'
 
 
 export type DialogWindowTitleProps = {
@@ -18,17 +16,21 @@ export const DialogWindowTitle = (props: DialogWindowTitleProps) => (
   }}>
     <Box display={'flex'} alignItems={'center'}>
       <IconButton size={'small'} style={{marginRight: '16px'}} onClick={props.onClose}>
-        <WindowCloseIcon style={{
-          color: '#c52', width: '20px', height: '20px'
-        }} />
+        <MaterialIcon icon={'cancel'} size={20} color={'#c52'} />
       </IconButton>
       <Typography color={'primary'} style={{flexGrow: 1}}>{props.title}</Typography>
       {props.onHelp !== undefined && (
         <Button
           onClick={props.onHelp}
           variant={'outlined'}
-          style={{fontSize: '.75em', padding: '6px 16px', color: '#181', borderColor: '#181'}}
-          startIcon={<HelpIcon fontSize={'small'} style={{color: '#181'}} />}
+          style={{
+            fontSize: '.75em',
+            padding: '6px 16px',
+            color: '#181',
+            borderColor: '#181',
+            lineHeight: 1.1
+          }}
+          startIcon={<MaterialIcon size={20} icon={'help'} color={'#181'} />}
         >
           {gettext("Help")}
         </Button>
